pig/agent/client_watcher
Explicit client-owner monitoring for transient run streams.
Types
Values
pub fn start(client: process.Pid, notify: fn() -> Nil) -> Watch
Notify the runtime if client exits while the runtime still owns the run.
Explicit client-owner monitoring for transient run streams.
pub fn start(client: process.Pid, notify: fn() -> Nil) -> Watch
Notify the runtime if client exits while the runtime still owns the run.