pig/agent/client_watcher

Explicit client-owner monitoring for transient run streams.

Types

A cancellable watch on the process responsible for a run’s client.

pub opaque type Watch

Values

pub fn start(client: process.Pid, notify: fn() -> Nil) -> Watch

Notify the runtime if client exits while the runtime still owns the run.

pub fn stop(watch: Watch) -> Nil

Stop watching after the run reaches terminality.

Search Document